# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import APIService, APIServiceCondition, APIServiceList, APIServiceSpec, APIServiceStatus, ServiceReference




__all__ = ['APIService', 'APIServiceCondition', 'APIServiceList', 'APIServiceSpec', 'APIServiceStatus', 'ServiceReference']

