# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import AWSElasticBlockStoreVolumeSource, AzureDiskVolumeSource, AzureFilePersistentVolumeSource, CSIPersistentVolumeSource, CephFSPersistentVolumeSource, CinderPersistentVolumeSource, FCVolumeSource, FlexPersistentVolumeSource, FlockerVolumeSource, GCEPersistentDiskVolumeSource, GlusterfsPersistentVolumeSource, HostPathVolumeSource, ISCSIPersistentVolumeSource, LocalVolumeSource, NFSVolumeSource, NodeSelector, NodeSelectorRequirement, NodeSelectorTerm, ObjectReference, PersistentVolumeSpec, PhotonPersistentDiskVolumeSource, PortworxVolumeSource, QuobyteVolumeSource, RBDPersistentVolumeSource, ScaleIOPersistentVolumeSource, SecretReference, StorageOSPersistentVolumeSource, TopologySelectorLabelRequirement, TopologySelectorTerm, VolumeNodeAffinity, VsphereVirtualDiskVolumeSource




__all__ = ['AWSElasticBlockStoreVolumeSource', 'AzureDiskVolumeSource', 'AzureFilePersistentVolumeSource', 'CSIPersistentVolumeSource', 'CephFSPersistentVolumeSource', 'CinderPersistentVolumeSource', 'FCVolumeSource', 'FlexPersistentVolumeSource', 'FlockerVolumeSource', 'GCEPersistentDiskVolumeSource', 'GlusterfsPersistentVolumeSource', 'HostPathVolumeSource', 'ISCSIPersistentVolumeSource', 'LocalVolumeSource', 'NFSVolumeSource', 'NodeSelector', 'NodeSelectorRequirement', 'NodeSelectorTerm', 'ObjectReference', 'PersistentVolumeSpec', 'PhotonPersistentDiskVolumeSource', 'PortworxVolumeSource', 'QuobyteVolumeSource', 'RBDPersistentVolumeSource', 'ScaleIOPersistentVolumeSource', 'SecretReference', 'StorageOSPersistentVolumeSource', 'TopologySelectorLabelRequirement', 'TopologySelectorTerm', 'VolumeNodeAffinity', 'VsphereVirtualDiskVolumeSource']

