# generated by https://github.com/puzl-cloud/kubesdk
from .v2 import ContainerResourceMetricSource, ContainerResourceMetricStatus, CrossVersionObjectReference, ExternalMetricSource, ExternalMetricStatus, HPAScalingPolicy, HPAScalingRules, HorizontalPodAutoscaler, HorizontalPodAutoscalerBehavior, HorizontalPodAutoscalerCondition, HorizontalPodAutoscalerList, HorizontalPodAutoscalerSpec, HorizontalPodAutoscalerStatus, MetricIdentifier, MetricSpec, MetricStatus, MetricTarget, MetricValueStatus, ObjectMetricSource, ObjectMetricStatus, PodsMetricSource, PodsMetricStatus, ResourceMetricSource, ResourceMetricStatus




__all__ = ['ContainerResourceMetricSource', 'ContainerResourceMetricStatus', 'CrossVersionObjectReference', 'ExternalMetricSource', 'ExternalMetricStatus', 'HPAScalingPolicy', 'HPAScalingRules', 'HorizontalPodAutoscaler', 'HorizontalPodAutoscalerBehavior', 'HorizontalPodAutoscalerCondition', 'HorizontalPodAutoscalerList', 'HorizontalPodAutoscalerSpec', 'HorizontalPodAutoscalerStatus', 'MetricIdentifier', 'MetricSpec', 'MetricStatus', 'MetricTarget', 'MetricValueStatus', 'ObjectMetricSource', 'ObjectMetricStatus', 'PodsMetricSource', 'PodsMetricStatus', 'ResourceMetricSource', 'ResourceMetricStatus']

