# generated by https://github.com/puzl-cloud/kubesdk
from .v1beta1 import ClusterTrustBundle, ClusterTrustBundleList, ClusterTrustBundleSpec




__all__ = ['ClusterTrustBundle', 'ClusterTrustBundleList', 'ClusterTrustBundleSpec']

