# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  apis__autoscaling__v1_openapi.json

from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *


@dataclass(slots=True, kw_only=True, frozen=True)
class RawExtension(LazyLoadModel):
    pass
