# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha2 import LeaseCandidate, LeaseCandidateList, LeaseCandidateSpec




__all__ = ['LeaseCandidate', 'LeaseCandidateList', 'LeaseCandidateSpec']

