# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha3 import CELDeviceSelector, DeviceSelector, DeviceTaint, DeviceTaintRule, DeviceTaintRuleList, DeviceTaintRuleSpec, DeviceTaintSelector




__all__ = ['CELDeviceSelector', 'DeviceSelector', 'DeviceTaint', 'DeviceTaintRule', 'DeviceTaintRuleList', 'DeviceTaintRuleSpec', 'DeviceTaintSelector']

