# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import UserInfo
from .v1beta1 import SelfSubjectReview, SelfSubjectReviewStatus




__all__ = ['UserInfo', 'SelfSubjectReview', 'SelfSubjectReviewStatus']

