# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import Endpoint, EndpointConditions, EndpointHints, EndpointPort, EndpointSlice, EndpointSliceList, ForNode, ForZone




__all__ = ['Endpoint', 'EndpointConditions', 'EndpointHints', 'EndpointPort', 'EndpointSlice', 'EndpointSliceList', 'ForNode', 'ForZone']

