# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha1 import GroupVersionResource, MigrationCondition, StorageVersionMigration, StorageVersionMigrationList, StorageVersionMigrationSpec, StorageVersionMigrationStatus




__all__ = ['GroupVersionResource', 'MigrationCondition', 'StorageVersionMigration', 'StorageVersionMigrationList', 'StorageVersionMigrationSpec', 'StorageVersionMigrationStatus']

