# generated by https://github.com/puzl-cloud/kubesdk
from .v1alpha2 import AllocationResult, DriverAllocationResult, DriverRequests, NamedResourcesAllocationResult, NamedResourcesAttribute, NamedResourcesFilter, NamedResourcesInstance, NamedResourcesIntSlice, NamedResourcesRequest, NamedResourcesResources, NamedResourcesStringSlice, PodSchedulingContext, PodSchedulingContextList, PodSchedulingContextSpec, PodSchedulingContextStatus, ResourceClaim, ResourceClaimConsumerReference, ResourceClaimList, ResourceClaimParameters, ResourceClaimParametersList, ResourceClaimParametersReference, ResourceClaimSchedulingStatus, ResourceClaimSpec, ResourceClaimStatus, ResourceClaimTemplate, ResourceClaimTemplateList, ResourceClaimTemplateSpec, ResourceClass, ResourceClassList, ResourceClassParameters, ResourceClassParametersList, ResourceClassParametersReference, ResourceFilter, ResourceHandle, ResourceRequest, ResourceSlice, ResourceSliceList, StructuredResourceHandle, VendorParameters




__all__ = ['AllocationResult', 'DriverAllocationResult', 'DriverRequests', 'NamedResourcesAllocationResult', 'NamedResourcesAttribute', 'NamedResourcesFilter', 'NamedResourcesInstance', 'NamedResourcesIntSlice', 'NamedResourcesRequest', 'NamedResourcesResources', 'NamedResourcesStringSlice', 'PodSchedulingContext', 'PodSchedulingContextList', 'PodSchedulingContextSpec', 'PodSchedulingContextStatus', 'ResourceClaim', 'ResourceClaimConsumerReference', 'ResourceClaimList', 'ResourceClaimParameters', 'ResourceClaimParametersList', 'ResourceClaimParametersReference', 'ResourceClaimSchedulingStatus', 'ResourceClaimSpec', 'ResourceClaimStatus', 'ResourceClaimTemplate', 'ResourceClaimTemplateList', 'ResourceClaimTemplateSpec', 'ResourceClass', 'ResourceClassList', 'ResourceClassParameters', 'ResourceClassParametersList', 'ResourceClassParametersReference', 'ResourceFilter', 'ResourceHandle', 'ResourceRequest', 'ResourceSlice', 'ResourceSliceList', 'StructuredResourceHandle', 'VendorParameters']

