# generated by https://github.com/puzl-cloud/kubesdk
#   filename:  version_openapi.json

from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime, timezone
from typing import ClassVar, Set

from kube_models.const import *
from kube_models.loader import *
from kube_models.loader import LazyLoadModel
from kube_models.resource import *


@dataclass(slots=True, kw_only=True, frozen=True)
class Info(LazyLoadModel):
    buildDate: str
    compiler: str
    gitCommit: str
    gitTreeState: str
    gitVersion: str
    goVersion: str
    major: str
    minor: str
    platform: str
    emulationMajor: str | None = None
    emulationMinor: str | None = None
    minCompatibilityMajor: str | None = None
    minCompatibilityMinor: str | None = None
