# generated by https://github.com/puzl-cloud/kubesdk
from .v1 import CustomResourceColumnDefinition, CustomResourceConversion, CustomResourceDefinition, CustomResourceDefinitionCondition, CustomResourceDefinitionList, CustomResourceDefinitionNames, CustomResourceDefinitionSpec, CustomResourceDefinitionStatus, CustomResourceDefinitionVersion, CustomResourceSubresourceScale, CustomResourceSubresourceStatus, CustomResourceSubresources, CustomResourceValidation, ExternalDocumentation, JSON, JSONSchemaProps, JSONSchemaPropsOrArray, JSONSchemaPropsOrBool, JSONSchemaPropsOrStringArray, SelectableField, ServiceReference, ValidationRule, WebhookClientConfig, WebhookConversion




__all__ = ['CustomResourceColumnDefinition', 'CustomResourceConversion', 'CustomResourceDefinition', 'CustomResourceDefinitionCondition', 'CustomResourceDefinitionList', 'CustomResourceDefinitionNames', 'CustomResourceDefinitionSpec', 'CustomResourceDefinitionStatus', 'CustomResourceDefinitionVersion', 'CustomResourceSubresourceScale', 'CustomResourceSubresourceStatus', 'CustomResourceSubresources', 'CustomResourceValidation', 'ExternalDocumentation', 'JSON', 'JSONSchemaProps', 'JSONSchemaPropsOrArray', 'JSONSchemaPropsOrBool', 'JSONSchemaPropsOrStringArray', 'SelectableField', 'ServiceReference', 'ValidationRule', 'WebhookClientConfig', 'WebhookConversion']

